<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_EMAIL"," ");
define("_RE","");
define("_SUBJECT","");
define("_PRIVATEMESSAGES"," ");
define("_CHECKALL"," ");
define("_FROM","");
define("_DATE","");
define("_DONTHAVEMESSAGES","    ");
define("_NOTREAD"," ");
define("_MSGSTATUS"," ");
define("_PRIVATEMESSAGE"," ");
define("_INDEX","");
define("_SENT","");
define("_PREVIOUSMESSAGE"," ");
define("_NEXTMESSAGE"," ");
define("_PROFILE","");
define("_ABOUTPOSTING"," ");
define("_ALLREGCANPOST","      ");
define("_TO","");
define("_MESSAGEICON"," ");
define("_MESSAGE","");
define("_HTML"," ");
define("_PMON","");
define("_PMOFF"," ");
define("_BBCODE"," BB");
define("_WROTE","");
define("_OPTIONS","");
define("_HTMLDISSABLE","     ");
define("_BBCODEDISSABLE"," <i> BB</i>   ");
define("_SMILEDISSABLE"," <i> </i>   ");
define("_CANCELREPLY"," ");
define("_CANCELSEND"," ");
define("_CLEAR","");
define("_SUBMIT","");
define("_USERNOTINDB","    .");
define("_CHECKNAMEANDTRY","      .");
define("_MSGPOSTED","  .");
define("_RETURNTOPMSG","    .");
define("_MSGDELETED","  .");
define("_BBGO","go");
define("_BBNEWPMSG"," ");
define("_BBNONEWPMSG","   ");
define("_BBTOTALPMSG"," ");
define("_BBEMPTYPMSG","   ");
define("_BBLOGIN","     ");
define("_BBPMSG"," ");
define("_BBINBOX"," ");
define("_BBSELECTFORUM"," ");
define("_BBNOFORUM"," ");
define("_BBBANNED","");
define("_CLICKSMILEBUTTONS","     :");
define("_CLICKCODEBUTTONS","         :");
define("_PRIVMSGERROR","   !");
define("_USERDOESNTEXIST","    ")
define("_DELETESELECTED"," ");
define("_SENDNEWMSG","  ");
define("_REPLY"," ");
define("_NOSUBJECT","   .");
define("_NOMESSAGE","  .   !");

?>